@@ -42,7 +42,15 @@ extern "C" {
 #endif // ]
 
 ///////////////////////////////////////////////////////////////////////////////
+//#define FF_ASSUME_NEW_CHANNEL_LAYOUT
+#if defined (FF_ASSUME_NEW_CHANNEL_LAYOUT) // [
+  // describe what is assumed ...
+	// "https://ffmpeg.org/doxygen/2.7/group__channel__mask__c.html"
+	// uint64_t 	av_get_channel_layout (const char *name);
+	// "https://cpp.hotexamples.com/examples/-/-/av_get_channel_layout_string/cpp-av_get_channel_layout_string-function-examples.html"
+#else // ] [
 #define FF_HOLZHAMMER
+#endif // ]
 #if defined (FF_HOLZHAMMER) // [
 // the "Holzhammer" is taken from "libavutil/internal.h"
 #if ! defined (FF_DISABLE_DEPRECATION_WARNINGS) // [
@@ -51,6 +59,13 @@ extern "C" {
 #if ! defined (FF_ENABLE_DEPRECATION_WARNINGS) // [
 #define FF_ENABLE_DEPRECATION_WARNINGS  _Pragma("GCC diagnostic warning \"-Wdeprecated-declarations\"")
 #endif // ]
+#else // ] [
+#if ! defined (FF_DISABLE_DEPRECATION_WARNINGS) // [
+#define FF_DISABLE_DEPRECATION_WARNINGS
+#endif // ]
+#if ! defined (FF_ENABLE_DEPRECATION_WARNINGS) // [
+#define FF_ENABLE_DEPRECATION_WARNINGS
+#endif // ]
 #endif // ]
 
 //#define FF_FIFO
@@ -106,6 +121,8 @@ extern "C" {
 #endif // ]
 
 typedef wchar_t ffchar_t;
+#define PBU_WIDEN2(x) L ## x
+#define PBU_WIDEN(x) PBU_WIDEN2(x)
 #else // ] [
 #define FF_GETOPT_LONG(argc,argv,optstring,longopts,longindex) \
     getopt_long(argc,argv,optstring,longopts,longindex)
